.. role:: hidden
    :class: hidden-section

gpytorch.models
===================================

.. automodule:: gpytorch.models
.. currentmodule:: gpytorch.models


Models for Exact GP Inference
-----------------------------

:hidden:`ExactGP`
~~~~~~~~~~~~~~~~~

.. autoclass:: ExactGP
   :members:


Models for Approximate GP Inference
-----------------------------------

:hidden:`ApproximateGP`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ApproximateGP
   :members:


Models for Deep GPs
-----------------------------------

:hidden:`deep_gps.DeepGP`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: gpytorch.models.deep_gps.DeepGP
   :members:

:hidden:`deep_gps.DeepGPLayer`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: gpytorch.models.deep_gps.DeepGPLayer
   :members:


Gaussian Process Latent Variable Models (GPLVM)
-------------------------------------------------------

:hidden:`gplvm.BayesianGPLVM`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: gpytorch.models.gplvm.BayesianGPLVM
   :members:

:hidden:`gplvm.PointLatentVariable`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: gpytorch.models.gplvm.PointLatentVariable
   :members:

:hidden:`gplvm.MAPLatentVariable`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: gpytorch.models.gplvm.MAPLatentVariable
   :members:

:hidden:`gplvm.VariationalLatentVariable`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: gpytorch.models.gplvm.VariationalLatentVariable
   :members:

Models for integrating with Pyro
-----------------------------------

:hidden:`PyroGP`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: PyroGP
   :members:
